==> node-validator-tool-1.0.1.tgz: package/tests/validator-test.js <==
'use strict';

process.on('uncaughtException', function (error)
{
    process.stdout.write('Test failed: ' + error + ' [' + __filename + ']');
});

const assert = require('assert');
const factory = require('../index');


// tests

let v;

assert.doesNotThrow(() =>
{   // without rules
    v = factory();
});

assert.throws(() =>
{   // invalid rule
    v = factory({
        'name': 'Jon'
    });
}, Error);

assert.doesNotThrow(() =>
{   // valid rule (lambda)
    v = factory('name', (name) =>
    {
        return name == 'Jon';
    });
});

// test module api
assert.ok(v.validate);
assert.ok(v.addRule);
assert.ok(v.remRule);
assert.ok(v.hasRule);

// test standard rules
assert.equal(v.validate('', 'email:null'), true);
assert.equal(v.validate('jon.snow@winterfell.north', 'email'), true);
assert.equal(v.validate('jon.snow_winterfell.north', 'email'), false);
assert.equal(v.validate('jon.snow_winterfell.north', 'email:null'), false);

assert.equal(v.validate('2016-07-19 10:35:22.000', 'datetime'), true);
assert.equal(v.validate('2055-12-01 12:00:00', 'datetime'), true);
assert.equal(v.validate('2055-12-01', 'datetime'), false);

assert.equal(v.validate('Hello world', 'text'), true);
assert.equal(v.validate('125 245', 'text'), true);
assert.equal(v.validate('', 'text'), false);

assert.equal(v.validate('23', 'number'), true);
assert.equal(v.validate('0', 'number'), true);
assert.equal(v.validate('23 35', 'number'), false);
assert.equal(v.validate('42x', 'number'), false);

assert.equal(v.validate('T', 'bool'), true);
assert.equal(v.validate('F', 'bool'), true);
assert.equal(v.validate('t', 'bool'), true);
assert.equal(v.validate('f', 'bool'), true);
assert.equal(v.validate('false', 'bool'), true);
assert.equal(v.validate('False', 'bool'), true);
assert.equal(v.validate('FALSE', 'bool'), true);
assert.equal(v.validate('0', 'bool'), false);
assert.equal(v.validate('1', 'bool'), false);

assert.equal(v.validate('WTF', 'abbr'), true);
assert.equal(v.validate('A3B', 'abbr'), false);
assert.equal(v.validate('omg', 'abbr'), false);
assert.equal(v.validate('123', 'abbr'), false);

assert.equal(v.validate('A1B2C3', 'alphanum'), true);
assert.equal(v.validate('A1B 2C', 'alphanum'), false);

assert.equal(v.validate('M', 'gender'), true);
assert.equal(v.validate('F', 'gender'), true);
assert.equal(v.validate('m', 'gender'), true);
assert.equal(v.validate('f', 'gender'), true);
assert.equal(v.validate('', 'gender'), false);
assert.equal(v.validate('MF', 'gender'), false);
assert.equal(v.validate('X', 'gender'), false);

assert.equal(v.validate('11000', 'zip'), true);
assert.equal(v.validate('110 00', 'zip'), true);
assert.equal(v.validate('SA 123', 'zip'), false);

assert.equal(v.validate('+42 702 555 111', 'phone'), true);
assert.equal(v.validate('0042 702 555 111', 'phone'), true);
assert.equal(v.validate('702555111', 'phone'), true);
assert.equal(v.validate('tel 702555111', 'phone'), false);

assert.ok(v.validate('GB', 'countrycode'));
assert.equal(v.validate('uk', 'countrycode'), false);
assert.equal(v.validate('SLO', 'countrycode'), false);

// test custom validator
assert.equal(v.validate('foo', /foo/), true);
assert.equal(v.validate('bar', /foo/), false);

assert.equal(v.validate('foo', (val) =>
{
    return val == 'foo';
}), true);
assert.equal(v.validate('foo', (val) =>
{
    return val == 'bar';
}), false);

// test add validator
v.addRule('countryCode', /^[A-Z]{2}$/);
assert.equal(v.validate('CZ', 'countryCode'), true);
assert.equal(v.validate('Cz', 'countryCode'), false);
assert.equal(v.validate('cz', 'countryCode'), false);
assert.equal(v.validate('C', 'countryCode'), false);
assert.equal(v.validate('CZZ', 'countryCode'), false);

v.addRule('adult', (age) =>
{
    return age >= 18;
});
assert.equal(v.validate(23, 'adult'), true);
assert.equal(v.validate(15, 'adult'), false);

assert.equal(v.hasRule('adult'), true);
v.remRule('adult');
assert.equal(v.hasRule('adult'), false);
assert.throws(() =>
{
    v.validate(32, 'adult');
});


// test output
process.stdout.write('Test OK [' + __filename + ']');

==> node-validator-tool-1.0.10.tgz: package/tests/validator-test.js <==
'use strict';
process.on('uncaughtException', function (error)
{
    process.stdout.write('Test failed: ' + error + ' [' + __filename + ']');
});

const assert = require('assert');
const factory = require('../index');


// tests

let v;

assert.doesNotThrow(() =>
{   // without rules
    v = factory.create();
});

assert.doesNotThrow(() =>
{   // valid rule (regex)
    v = factory.create('name', /^Jon$/);
});

assert.doesNotThrow(() =>
{   // valid rule (lambda)
    v = factory.create('name', (name) =>
    {
        return name == 'Jon';
    });
});

assert.doesNotThrow(() =>
{   // valid rule (named validator)
    v = factory.create('name', 'text');
});

assert.throws(() =>
{   // invalid rule
    v = factory.create({
        'name': 'Jon'
    });
}, Error);

// test module api
assert.ok(v.validate);
assert.ok(v.addRule);
assert.ok(v.removeRule);
assert.ok(v.hasRule);
assert.ok(v.hasErrors);
assert.ok(v.getErrors);

// test standard rules
assert.equal(v.validate('jon.snow@winterfell.north', 'email'), true);
assert.equal(v.validate('jon.snow_winterfell.north', 'email'), false);
assert.equal(v.validate('jon.snow_winterfell.north', 'email:null'), false);
assert.equal(v.validate('', 'email:null'), true);

assert.equal(v.validate('2016-07-19 10:35:22.000', 'datetime'), true);
assert.equal(v.validate('2055-12-01 12:00:00', 'datetime'), true);
assert.equal(v.validate('2055-12-01', 'datetime'), false);

assert.equal(v.validate('Hello world', 'text'), true);
assert.equal(v.validate('125 245', 'text'), true);
assert.equal(v.validate('', 'text'), false);
assert.equal(v.validate('', 'text:null'), true);

assert.equal(v.validate('23', 'number'), true);
assert.equal(v.validate('0', 'number'), true);
assert.equal(v.validate('23 35', 'number'), false);
assert.equal(v.validate('42x', 'number'), false);

assert.equal(v.validate('T', 'bool'), true);
assert.equal(v.validate('F', 'bool'), true);
assert.equal(v.validate('t', 'bool'), true);
assert.equal(v.validate('f', 'bool'), true);
assert.equal(v.validate('false', 'bool'), true);
assert.equal(v.validate('False', 'bool'), true);
assert.equal(v.validate('FALSE', 'bool'), true);
assert.equal(v.validate('0', 'bool'), false);
assert.equal(v.validate('1', 'bool'), false);

assert.equal(v.validate('WTF', 'abbr'), true);
assert.equal(v.validate('A3B', 'abbr'), false);
assert.equal(v.validate('omg', 'abbr'), false);
assert.equal(v.validate('123', 'abbr'), false);

assert.equal(v.validate('A1B2C3', 'alphanum'), true);
assert.equal(v.validate('A1B 2C', 'alphanum'), false);

assert.equal(v.validate('M', 'gender'), true);
assert.equal(v.validate('F', 'gender'), true);
assert.equal(v.validate('m', 'gender'), true);
assert.equal(v.validate('f', 'gender'), true);
assert.equal(v.validate('', 'gender'), false);
assert.equal(v.validate('MF', 'gender'), false);
assert.equal(v.validate('X', 'gender'), false);

assert.equal(v.validate('11000', 'zip'), true);
assert.equal(v.validate('110 00', 'zip'), true);
assert.equal(v.validate('SA 123', 'zip'), false);

assert.equal(v.validate('+42 702 555 111', 'phone'), true);
assert.equal(v.validate('0042 702 555 111', 'phone'), true);
assert.equal(v.validate('702555111', 'phone'), true);
assert.equal(v.validate('tel 702555111', 'phone'), false);

assert.ok(v.validate('GB', 'countrycode'));
assert.equal(v.validate('uk', 'countrycode'), false);
assert.equal(v.validate('SLO', 'countrycode'), false);

// test custom validator
assert.equal(v.validate('foo', /foo/), true);
assert.equal(v.validate('bar', /foo/), false);
assert.equal(v.validate('', /^foo$/), false);
assert.equal(v.validate('', /^$/), true);
assert.equal(v.validate('', /^$|^foo$/), true);


assert.equal(v.validate('foo', (val) => {
    return val == 'foo';
}), true);
assert.equal(v.validate('foo', (val) => {
    return val == 'bar';
}), false);

// test add validator
v.addRule('countryCode', /^[A-Z]{2}$/);
assert.equal(v.validate('CZ', 'countryCode'), true);
assert.equal(v.validate('Cz', 'countryCode'), false);
assert.equal(v.validate('cz', 'countryCode'), false);
assert.equal(v.validate('C', 'countryCode'), false);
assert.equal(v.validate('CZZ', 'countryCode'), false);

v.addRule('adult', (age) => {
    return age >= 18;
});
assert.equal(v.validate(23, 'adult'), true);
assert.equal(v.validate(15, 'adult'), false);

assert.equal(v.hasRule('adult'), true);
v.removeRule('adult');
assert.equal(v.hasRule('adult'), false);
assert.throws(() => {
    v.validate(32, 'adult');
});


let item = {
    countryCode: 'ES',
    name: 'Spain',
    deep: {
        path: 'value'
    },
    "deep.jungle": 'you bet'
};

v.addRule('name', (name) => name.length > 3);
assert.doesNotThrow(() => {
    let result = v.validateAll(item);
    assert.ok(result);
    assert.equal(v.hasErrors(), false);
});

v.addRule('regions', 'number');
assert.doesNotThrow(() => {
    let result = v.validateAll(item);
    assert.equal(result, false);
    assert.ok(v.hasErrors());
    assert.ok(v.getErrors().regions);
});

v.addRule('regions', 'number:null');
assert.doesNotThrow(() => {
    let result = v.validateAll(item);
    assert.equal(result, true);
    assert.equal(v.hasErrors(), false);
});

item.regions = 'all';
assert.doesNotThrow(() => {
    let result = v.validateAll(item);
    assert.equal(result, false);
    assert.equal(v.hasErrors(), true);
    assert.ok(v.getErrors().regions);
});
delete item.regions;

v.addRule('deep.path', /value/);
assert.doesNotThrow(() => {
    let result = v.validateAll(item);
    assert.ok(result);
    assert.equal(v.hasErrors(), false);
    assert.deepEqual(v.getErrors(), {});
});

v.addRule('deep.jungle', /you bet/);
assert.doesNotThrow(() => {
    let result = v.validateAll(item);
    assert.ok(result);
    assert.equal(v.hasErrors(), false);
    assert.deepEqual(v.getErrors(), {});
});

// test output
process.stdout.write('Test OK [' + __filename + ']');
